<no title> — BCI-Framework documentation

bci_framework.default_extensions.Visual_working_memory.points.add_point(points: List[(p1, p2) point], d: Union[float, int], margin: Union[float, int]) → None

  Add a point that comply with the rule of minimum distance.

bci_framework.default_extensions.Visual_working_memory.points.distance(p1: (p1, p2) point, p2: (p1, p2) point) → float

  Euclidean distance.

bci_framework.default_extensions.Visual_working_memory.points.get_points(N: int, d: Union[float, int], margin: Union[float, int]) → List[(p1, p2) point]

  Generate N points that comply with the rule of minimum distance.

bci_framework.default_extensions.Visual_working_memory.points.point(margin: Union[float, int]) → (p1, p2) point

  Generate a random point, inside a fixed area.